/* roughness_37override.pov
 * Persistence of Vision Ray Tracer scene description file
 *
 * Demonstrate how roughness override requires a specular albedo restatement.
 * Finish-level Fresnel is not used.
 *
 * Copyright © 2019 Richard Callwood III.
 *
 * 2019-Oct-12  Created.
 */
// +KFF3
#version 3.7;

#include "screen.inc"

Set_Camera (<0, 1, -5.6713>, <0, 1, 0>, 38.8508)
Set_Camera_Aspect_Ratio (4/3)
#default
{ finish
  { diffuse 0.6 ambient rgb <0.16041, 0.16041, 0.16041>
    emission 0
  }
}
global_settings
{ assumed_gamma 1
  max_trace_level 50
  photons
  { spacing 0.002
    autostop 0
  }
  mm_per_unit 304.800
}

light_source
{ <-3.3125, 7.6250, -5.7374>,
  rgb <4045, 4045, 4045>
  fade_power 2 fade_distance 0.10417
  spotlight point_at <0, 1, 0> radius 45 falloff 90
}

box
{ -1, 1 scale <7, 9, 7> hollow
  pigment { rgb 1 }
}

plane
{ y, 0
  pigment { checker rgb 0.05 rgb 1 }
  translate -0.001 * y
}

//---------------------------- THE DEMONSTRATION -------------------------------

#declare HIGHLIGHT = 0.05;
#declare SMOOTH = 0.0005;
#declare ROUGH = 0.02;
#declare BUMP_SIZE = 0.2;
#declare MICROSCALE = 0.0001;

#declare f_Gloss = finish
{ reflection { 0 1 fresnel } conserve_energy
  specular albedo HIGHLIGHT roughness SMOOTH
  ambient 0 diffuse 0
}
#declare t_Glass = texture
{ pigment { rgbf 1 }
  finish { f_Gloss }
}
#declare t_Frost1 = texture
{ pigment { rgbf 1 }
  finish { f_Gloss roughness ROUGH }
  normal { bumps BUMP_SIZE scale MICROSCALE }
}
#declare t_Frost2 = texture
{ pigment { rgbf 1 }
  finish { f_Gloss roughness ROUGH specular albedo HIGHLIGHT }
  normal { bumps BUMP_SIZE scale MICROSCALE }
}

sphere
{ y, 1
  #switch (frame_number)
    #case (3) texture { t_Frost2 } #break
    #case (2) texture { t_Frost1 } #break
    #case (1)
    #else texture { t_Glass }
  #end
  interior { ior 1.5 }
  photons { target collect off reflection on refraction on }
}

//--------------------------------- CAPTIONS -----------------------------------

#macro Annotate (S, uv_Posn)
  Screen_Object
  ( text { ttf "cyrvetic" S 0.001, 0 pigment { rgb 0 } scale 0.065 },
    uv_Posn, <0.015, 0.01>, yes, 1
  )
#end

#declare s_Case = array[5]
{ "?", "No override", "Override roughness only",
  "Override roughness and specular albedo", "?"
}
Annotate (s_Case [min (frame_number, 4)], <0, 1>)
Annotate ("3.7 fixed highlight", <0, 0.92>)
